@@ -512,12 +512,14 @@ void Recurrence::shiftTimes(const QTimeZone &oldTz, const QTimeZone &newTz)
     QHash<QDateTime, Period> oldPeriods = d->mRDateTimePeriods;
 
     for (auto &rDt : d->mRDateTimes) {
-        auto periodIt = oldPeriods.find(rDt);
-        periodIt->shiftTimes(oldTz, newTz);
-        rDt = rDt.toTimeZone(oldTz);
-        rDt.setTimeZone(newTz);
-        // Now there are QDateTime objects in the hash? is this shifting times?
-        d->mRDateTimePeriods.insert(rDt, *periodIt);
+        auto period = oldPeriods.value(rDt, Period());
+        if (period.isValid()) {
+            period.shiftTimes(oldTz, newTz);
+            rDt = rDt.toTimeZone(oldTz);
+            rDt.setTimeZone(newTz);
+            // Now there are QDateTime objects in the hash? is this shifting times?
+            d->mRDateTimePeriods.insert(rDt, period);
+        }
     }
 
     for (auto &exDt : d->mExDateTimes) {
